@@ -10,6 +10,7 @@ EmailMessage = "maltego.STIX2.email-message"
 File = "maltego.STIX2.file"
 Grouping = "maltego.STIX2.grouping"
 Identity = "maltego.STIX2.identity"
+Incident = "maltego.STIX2.incident"
 Indicator = "maltego.STIX2.indicator"
 Infrastructure = "maltego.STIX2.infrastructure"
 IntrusionSet = "maltego.STIX2.intrusion-set"
@@ -38,7 +39,6 @@ WindowsRegistryKey = "maltego.STIX2.windows-registry-key"
 XOpenctiCryptocurrencyWallet = "maltego.STIX2.x-opencti-cryptocurrency-wallet"
 XOpenctiCryptographicKey = "maltego.STIX2.x-opencti-cryptographic-key"
 XOpenctiHostname = "maltego.STIX2.x-opencti-hostname"
-XOpenctiIncident = "maltego.STIX2.x-opencti-incident"
 XOpenctiText = "maltego.STIX2.x-opencti-text"
 XOpenctiUserAgent = "maltego.STIX2.x-opencti-user-agent"
 X509Certificate = "maltego.STIX2.x509-certificate"
